import type { RouteRecordRaw } from 'vue-router'

export function useMenu() {
  const menuStore = useMenuStore()
  const userStore = useUserStore()
  const { resolve } = useRouter()

  /** 判断给定的route中是否具有给定perms列表的权限 */
  function hasPermission(route: RouteRecordRaw, perms: any[] = []) {
    if (!route.meta?.perm) {
      return true
    }

    // 递归寻找子节点perm
    if (route.meta?.perm === true && route.children?.length) {
      return filterAsyncRoutes(route.children, perms).length
    }

    // 否则直接通过perm进行判断
    return perms.includes(
      Array.isArray(route.meta?.perm)
        ? route.meta.perm[0]?.perm
        : route.meta?.perm,
    )
  }

  // 过滤掉所有perm不匹配的路由
  function filterAsyncRoutes(routes: RouteRecordRaw[], perms: any[]) {
    return routes.reduce((rs: RouteRecordRaw[], route) => {
      if (hasPermission(route, perms)) {
        rs.push({
          ...route,
          children: route.children ? filterAsyncRoutes(route.children, perms) : [],
        })
      }
      return rs
    }, [])
  }

  async function generateRoutes() {
    const perms = userStore.userInfo?.perms ?? ['role', 'role/post']
    menuStore.menuList = filterAsyncRoutes(getRoutes(), perms)
  }

  function getMenuList(routes: RouteRecordRaw[]) {
    return routes.reduce((rs: RouteRecordRaw[], route) => {
      if (!route.meta?.hidden && !route.meta?.hideInMenu) {
        rs.push({
          ...route,
          path: resolve(<string>route.redirect || route).path,
          children: route.children ? getMenuList(route.children) : [],
        })
      }
      return rs
    }, []).sort((a, b) => {
      return (a.meta?.order || 999) - (b.meta?.order || 999)
    })
  }

  const menuList = computed(() => getMenuList(menuStore.menuList))

  return {
    menuList,
    generateRoutes,
  }
}
