import { acceptHMRUpdate, defineStore } from 'pinia'
import { _merge } from '~/utils'

const { VITE_APP_TITLE } = import.meta.env

export const useSiteConfigStore = defineStore('SITE_CONFIG', () => {
  const { t } = useI18n()
  const initState: DefineSiteOptions = {
    logo: 'logo.png',
    title: VITE_APP_TITLE,
    copyright: '2022-present NoahLan',
    links: [
      {
        label: t('layout.footer.onlineDocument'),
        url: 'https://nadm.noahlan.cn/docs',
      },
      {
        icon: 'uim:github',
        url: 'https://git.noahlan.cn/n-admin',
      },
    ],
  }

  let state = $ref<DefineSiteOptions>(Object.assign({}, initState))

  function $reset() {
    state = Object.assign({}, initState)
  }

  function setSiteConfig(configs: DeepPartial<DefineSiteOptions>) {
    state = _merge(state, configs)
  }

  return {
    $state: state,
    ...toRefs(state),
    $reset,
    setSiteConfig,
  }
}, {
  persist: true,
})

if (import.meta.hot)
  import.meta.hot.accept(acceptHMRUpdate(useSiteConfigStore as any, import.meta.hot))
