import fs from 'node:fs/promises'
import {
  defineConfig,
  presetAttributify,
  presetIcons,
  presetTypography,
  presetUno,
  presetWebFonts,
  transformerDirectives,
  transformerVariantGroup,
} from 'unocss'

export default defineConfig({
  shortcuts: [],
  presets: [
    presetUno(),
    presetAttributify(),
    presetIcons({
      scale: 1.0,
      warn: true,
      cdn: 'https://esm.sh/',
      collections: {
        'nl-logo': () => fs.readFile('./public/favicon.svg', 'utf-8'),
        'carbon': () => import('@iconify-json/carbon/icons.json').then(i => i.default),
        'ant-design': () => import('@iconify-json/ant-design/icons.json').then(i => i.default),
        'emojione': () => import('@iconify-json/emojione/icons.json').then(i => i.default),
        'gridicons': () => import('@iconify-json/gridicons/icons.json').then(i => i.default),
      },
    }),
    presetTypography(),
    presetWebFonts({
      fonts: {
        sans: 'DM Sans',
        serif: 'DM Serif Display',
        mono: 'DM Mono',
      },
    }),
  ],
  transformers: [
    transformerDirectives(),
    transformerVariantGroup(),
  ],
  safelist: 'prose m-auto text-left i-carbon-home i-carbon-3d-cursor'.split(' '),
})
